==> pyvsc-0.0.1.20200429.2-py2.py3-none-any.whl: vsc/model/field_model.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# Created on Jul 27, 2019
#
# @author: ballance

from vsc.model.expr_indexed_field_ref_model import ExprIndexedFieldRefModel
from vsc.model.expr_fieldref_model import ExprFieldRefModel
from vsc.model.source_info import SourceInfo



class FieldModel(object):
    
    def __init__(self, name):
        self.parent       = None
        self.idx          = -1
        self.name         = name
        self.srcinfo_decl = None
        self.srcinfo_inst = None
    
    def build(self, builder):
        raise Exception("build unimplemented")

    def pre_randomize(self):
        pass

    def post_randomize(self):
        pass
    
    @property
    def fullname(self):
        ret = self.name
        p = self.parent
        
        while p is not None:
            ret = p.name + "." + ret
            p = p.parent
            
        return ret
    
    def expr(self):
        """Returns a field-reference expression for this field"""
        return ExprFieldRefModel(self)
    
    def get_indexed_fieldref_expr(self):
        if self.parent is None:
            raise Exception("Field has no parent")
        else:
            idx_l = []
            p = self.parent
            s = self
            while p is not None:
                idx_l.insert(0, s.idx)
                s = p
                p = p.parent
            
            return ExprIndexedFieldRefModel(s, idx_l)

==> pyvsc-0.0.1.20200516.3-py2.py3-none-any.whl: vsc/model/field_model.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# Created on Jul 27, 2019
#
# @author: ballance

from vsc.model.expr_indexed_field_ref_model import ExprIndexedFieldRefModel
from vsc.model.expr_fieldref_model import ExprFieldRefModel
from vsc.model.source_info import SourceInfo



class FieldModel(object):
    
    def __init__(self, name):
        self.parent       = None
        self.idx          = -1
        self.name         = name
        self.srcinfo_decl = None
        self.srcinfo_inst = None
    
    def build(self, builder):
        raise Exception("FieldModel::build unimplemented for type " + str(type(self)))

    def pre_randomize(self):
        pass

    def post_randomize(self):
        pass
    
    @property
    def fullname(self):
        ret = self.name
        p = self.parent
        
        while p is not None:
            if p.name is not None:
                ret = p.name + "." + ret
            p = p.parent
            
        return ret
    
    def expr(self):
        """Returns a field-reference expression for this field"""
        return ExprFieldRefModel(self)
    
    def get_indexed_fieldref_expr(self):
        if self.parent is None:
            raise Exception("Field has no parent")
        else:
            idx_l = []
            p = self.parent
            s = self
            while p is not None:
                idx_l.insert(0, s.idx)
                s = p
                p = p.parent
            
            return ExprIndexedFieldRefModel(s, idx_l)
